@@ -443,9 +443,9 @@ tools = [
 ['shapes_transect', 0, 'Transect through polygon shapefile'],
 ['sim_cellular_automata', 0, 'Conway\'s Game of Life'],
 ['sim_cellular_automata', 1, 'Wa-Tor'],
-['sim_ecosystems_hugget', 0, '01: A Simple Litter System'],
-['sim_ecosystems_hugget', 1, '02: Carbon Cycle Simulation for Terrestrial Biomass'],
-['sim_ecosystems_hugget', 2, '03: Spatially Distributed Simulation of Soil Nitrogen Dynamics'],
+['sim_ecosystems_hugget', 0, 'A Simple Litter System'],
+['sim_ecosystems_hugget', 1, 'Carbon Cycle Simulation for Terrestrial Biomass'],
+['sim_ecosystems_hugget', 2, 'Spatially Distributed Simulation of Soil Nitrogen Dynamics'],
 ['sim_erosion', 0, 'MMF-SAGA Soil Erosion Model'],
 ['sim_fire_spreading', 0, 'Fire Risk Analysis'],
 ['sim_fire_spreading', 1, 'Simulation'],
@@ -517,7 +517,7 @@ tools = [
 ['ta_hydrology', 10, 'Cell Balance'],
 ['ta_hydrology', 13, 'Edge Contamination'],
 ['ta_hydrology', 15, 'SAGA Wetness Index'],
-['ta_hydrology', 16, 'Lake Flood'],
+['ta_hydrology', 16, '[deprecated] Lake Flood'],
 ['ta_hydrology', 18, 'Flow Accumulation (Mass-Flux Method)'],
 ['ta_hydrology', 19, 'Flow Width and Specific Catchment Area'],
 ['ta_hydrology', 20, 'Topographic Wetness Index (TWI)'],
@@ -816,5 +816,12 @@ tools = [
 ['shapes_lines', 11, 'Split Lines'],
 ['sim_hydrology', 12, 'Glugla Coefficient'],
 ['statistics_grid', 21, 'Grid Histogram'],
-['imagery_tools', 16, 'Import Sentinel-3 OLCI Scene']
+['imagery_tools', 16, 'Import Sentinel-3 OLCI Scene'],
+['ta_hydrology', 32, 'Terrain Flooding'],
+['vis_3d_viewer', 0, 'TIN Viewer'],
+['vis_3d_viewer', 1, 'Point Cloud Viewer'],
+['vis_3d_viewer', 2, '3D Shapes Viewer'],
+['vis_3d_viewer', 3, 'Globe Viewer for Grids'],
+['vis_3d_viewer', 4, 'Multiple Grids Viewer'],
+['vis_3d_viewer', 5, 'Grid Collection Viewer']
 ]
