@@ -247,6 +247,14 @@ CSG_DateTime & CSG_DateTime::Set_Year(int Value)
 	return( *this );
 }
 
+//---------------------------------------------------------
+CSG_DateTime & CSG_DateTime::Set_DayOfYear(unsigned short Value)
+{
+	m_pDateTime->SetToYearDay(Value);
+
+	return( *this );
+}
+
 //---------------------------------------------------------
 CSG_DateTime & CSG_DateTime::Set_To_Current(void)
 {
