@@ -646,16 +646,19 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Choice );	}
 
-	void						Set_Items				(const SG_Char *String);
+	bool						Del_Items				(void);
+	bool						Add_Item				(const CSG_String &Item, const CSG_String &Data = "");
+
+	bool						Set_Items				(const SG_Char *String);
 	CSG_String					Get_Items				(void)		const;
 
 	const SG_Char *				Get_Item				(int Index)	const;
 	CSG_String					Get_Item_Data			(int Index)	const;
 
+	CSG_String					Get_Data				(void)				const;
+	bool						Get_Data				(CSG_String &Value)	const;
 	bool						Get_Data				(int        &Value)	const;
 	bool						Get_Data				(double     &Value)	const;
-	bool						Get_Data				(CSG_String &Value)	const;
-	CSG_String					Get_Data				(void)				const;
 
 	int							Get_Count				(void)	const	{	return( m_Items.Get_Count() );	}
 
@@ -666,7 +669,7 @@ protected:
 
 	int							m_Value;
 
-	CSG_Strings					m_Items;
+	CSG_Strings					m_Items, m_Data;
 
 
 	virtual int					_Set_Value				(int               Value);
