@@ -288,28 +288,36 @@ bool CSG_Tool::Execute(bool bAddHistory)
 	{
 		Parameters.Msg_String(false);
 
+	//	SG_UI_Process_Set_Busy(true, CSG_String::Format("%s: %s...", _TL("Executing"), Get_Name().c_str()));
+		CSG_DateTime Started(CSG_DateTime::Now());
+
 ///////////////////////////////////////////////////////////
-#if !defined(_DEBUG) && !defined(_OPENMP) && defined(_SAGA_MSW)
+//#if !defined(_DEBUG)
 #define _TOOL_EXCEPTION
-	__try
+	try
 	{
-#endif
+//#endif
 ///////////////////////////////////////////////////////////
 
-		CSG_DateTime Started(CSG_DateTime::Now());
 		bResult = On_Execute();
-		CSG_TimeSpan Span = CSG_DateTime::Now() - Started;
 
 ///////////////////////////////////////////////////////////
 #ifdef _TOOL_EXCEPTION
 	}	// try
-	__except(1)
+	catch(const std::exception &Exception)
 	{
-		Message_Dlg("Tool caused access violation!");
-	}	// except(1)
-#endif
+		Message_Dlg(Exception.what()            , CSG_String::Format("%s | %s", Get_Name().c_str(), _TL("Access violation!")));
+	}
+	catch(...)
+	{
+		Message_Dlg(_TL("unspecified exception"), CSG_String::Format("%s | %s", Get_Name().c_str(), _TL("Access violation!")));
+	}
+	#endif
 ///////////////////////////////////////////////////////////
 
+		CSG_TimeSpan Span = CSG_DateTime::Now() - Started;
+	//	SG_UI_Process_Set_Busy(false);
+
 		_Synchronize_DataObjects();
 
 		if( !Process_Get_Okay(false) )
@@ -1413,6 +1421,10 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 				Script	+= Prefix + CSG_String::Format("%s=%s", GET_ID1(p), p->asString());
 			break;
 
+        case PARAMETER_TYPE_Color            :
+            Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), SG_Color_To_Text(p->asColor()).c_str());
+            break;
+
 		case PARAMETER_TYPE_Double           :
 		case PARAMETER_TYPE_Degree           :
 			Script	+= Prefix + CSG_String::Format("%s=%g", GET_ID1(p), p->asDouble());
@@ -1502,6 +1514,10 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 					}
 				}
 			}
+			else
+			{
+				Script	+= Prefix + CSG_String::Format("%s=\"%s\"", GET_ID1(p), p->Get_Name());
+			}
 			break;
 		}
 	}
@@ -1675,6 +1691,10 @@ void CSG_Tool::_Get_Script_Python(CSG_String &Script, CSG_Parameters *pParameter
 			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), p->asString());
 			break;
 
+        case PARAMETER_TYPE_Color          :
+            Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', '%s')\n", ID.c_str(), SG_Color_To_Text(p->asColor()).c_str());
+            break;
+
 		case PARAMETER_TYPE_Double         :
 		case PARAMETER_TYPE_Degree         :
 			Script	+= CSG_String::Format("    Tool.Set_Parameter('%s', %g)\n", ID.c_str(), p->asDouble());
