@@ -80,17 +80,17 @@ enum
 
 //---------------------------------------------------------
 BEGIN_EVENT_TABLE(CSG_3DView_Panel, wxPanel)
-	EVT_SIZE		(CSG_3DView_Panel::On_Size)
-	EVT_PAINT		(CSG_3DView_Panel::On_Paint)
-	EVT_KEY_DOWN	(CSG_3DView_Panel::On_Key_Down)
-	EVT_LEFT_DOWN	(CSG_3DView_Panel::On_Mouse_LDown)
-	EVT_LEFT_UP		(CSG_3DView_Panel::On_Mouse_LUp)
-	EVT_RIGHT_DOWN	(CSG_3DView_Panel::On_Mouse_RDown)
-	EVT_RIGHT_UP	(CSG_3DView_Panel::On_Mouse_RUp)
-	EVT_MIDDLE_DOWN	(CSG_3DView_Panel::On_Mouse_MDown)
-	EVT_MIDDLE_UP	(CSG_3DView_Panel::On_Mouse_MUp)
-	EVT_MOTION		(CSG_3DView_Panel::On_Mouse_Motion)
-	EVT_MOUSEWHEEL	(CSG_3DView_Panel::On_Mouse_Wheel)
+	EVT_SIZE       (CSG_3DView_Panel::On_Size)
+	EVT_PAINT      (CSG_3DView_Panel::On_Paint)
+	EVT_KEY_DOWN   (CSG_3DView_Panel::On_Key_Down)
+	EVT_LEFT_DOWN  (CSG_3DView_Panel::On_Mouse_LDown)
+	EVT_LEFT_UP    (CSG_3DView_Panel::On_Mouse_LUp)
+	EVT_RIGHT_DOWN (CSG_3DView_Panel::On_Mouse_RDown)
+	EVT_RIGHT_UP   (CSG_3DView_Panel::On_Mouse_RUp)
+	EVT_MIDDLE_DOWN(CSG_3DView_Panel::On_Mouse_MDown)
+	EVT_MIDDLE_UP  (CSG_3DView_Panel::On_Mouse_MUp)
+	EVT_MOTION     (CSG_3DView_Panel::On_Mouse_Motion)
+	EVT_MOUSEWHEEL (CSG_3DView_Panel::On_Mouse_Wheel)
 END_EVENT_TABLE()
 
 
@@ -112,6 +112,12 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 		_TL("")
 	);
 
+	m_Parameters.Add_Double("NODE_GENERAL",
+		"Z_SCALE"		, _TL("Exaggeration"),
+		_TL(""),
+		1.
+	);
+
 	m_Parameters.Add_Choice("NODE_GENERAL",
 		"CENTRAL"		, _TL("Projection"),
 		_TL(""),
@@ -124,7 +130,7 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	m_Parameters.Add_Double("CENTRAL",
 		"CENTRAL_DIST"	, _TL("Central Projection Distance"),
 		_TL(""),
-		m_Projector.Get_Central_Distance(), 1., true
+		m_Projector.Get_Central_Distance(), 0.1, true
 	);
 
 	m_Parameters.Add_Color("NODE_GENERAL",
@@ -139,10 +145,26 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 		true
 	);
 
-	m_Parameters.Add_Bool("NODE_GENERAL",
-		"LABELS"		, _TL("Labels"),
+	m_Parameters.Add_Choice("NODE_GENERAL",
+		"LABELS"		, _TL("Axis Labeling"),
 		_TL(""),
-		false
+		CSG_String::Format("%s|%s|%s",
+			_TL("all"),
+			_TL("horizontal"),
+			_TL("none")
+		), m_Labels
+	);
+
+	m_Parameters.Add_Int("LABELS",
+		"LABEL_RES"		, _TL("Resolution"),
+		_TL(""),
+		m_Label_Res, 20, true, 1000, true
+	);
+
+	m_Parameters.Add_Double("LABELS",
+		"LABEL_SCALE"	, _TL("Size"),
+		_TL(""),
+		m_Label_Scale, 0.1, true, 10., true
 	);
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
@@ -160,7 +182,7 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	m_Parameters.Add_Double("STEREO",
 		"STEREO_DIST"	, _TL("Stereo Eye Distance [Degree]"),
 		_TL(""),
-		1., 0., true
+		1.
 	);
 
 	//-----------------------------------------------------
@@ -217,7 +239,7 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	m_pPlay->Add_Field(_TL("Central Distance"), SG_DATATYPE_Double);
 	m_pPlay->Add_Field(_TL("Steps to Next"   ), SG_DATATYPE_Int   );
 
-	m_Play_State	= SG_3DVIEW_PLAY_STOP;
+	m_Play_State = SG_3DVIEW_PLAY_STOP;
 }
 
 
@@ -245,11 +267,11 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 //---------------------------------------------------------
 int CSG_3DView_Panel::_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 {
-	CSG_Parameters	*pParameters	= pParameter ? pParameter->Get_Parameters() : NULL;
+	CSG_Parameters *pParameters = pParameter ? pParameter->Get_Parameters() : NULL;
 
 	if( pParameters )
 	{
-		CSG_3DView_Panel	*pPanel	= (CSG_3DView_Panel *)pParameters->Get_Owner();
+		CSG_3DView_Panel *pPanel = (CSG_3DView_Panel *)pParameters->Get_Owner();
 
 		if( Flags & PARAMETER_CHECK_VALUES )
 		{
@@ -291,9 +313,74 @@ int CSG_3DView_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 		pParameters->Set_Enabled("STEREO_DIST" , pParameter->asBool());
 	}
 
+	if( pParameter->Cmp_Identifier("LABELS") )
+	{
+		pParameter->Set_Children_Enabled(pParameter->asInt() != 2);
+	}
+
 	return( 1 );
 }
 
+//---------------------------------------------------------
+bool CSG_3DView_Panel::Parameter_Value_Toggle(const CSG_String &ID, bool bUpdate)
+{
+	CSG_Parameter *pParameter = m_Parameters(ID);
+
+	if( !pParameter )
+	{
+		return( false );
+	}
+
+	switch( pParameter->Get_Type() )
+	{
+	default:
+		return( false );
+
+	case PARAMETER_TYPE_Bool  :
+		pParameter->Set_Value(pParameter->asBool() ? 0 : 1);
+		break;
+
+	case PARAMETER_TYPE_Choice:
+		pParameter->Set_Value((pParameter->asInt() + 1) % pParameter->asChoice()->Get_Count());
+		break;
+	}
+
+	if( bUpdate )
+	{
+		Update_View(); Update_Parent();
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_3DView_Panel::Parameter_Value_Add(const CSG_String &ID, double Value, bool bUpdate)
+{
+	CSG_Parameter *pParameter = m_Parameters(ID);
+
+	if( !pParameter )
+	{
+		return( false );
+	}
+
+	switch( pParameter->Get_Type() )
+	{
+	default:
+		return( false );
+
+	case PARAMETER_TYPE_Int: case PARAMETER_TYPE_Double:
+		pParameter->Set_Value(pParameter->asDouble() + Value);
+		break;
+	}
+
+	if( bUpdate )
+	{
+		Update_View(); Update_Parent();
+	}
+
+	return( false );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -305,7 +392,9 @@ void CSG_3DView_Panel::Update_Statistics(void)
 
 //---------------------------------------------------------
 void CSG_3DView_Panel::Update_Parent(void)
-{}
+{
+	((CSG_3DView_Dialog *)GetParent())->Update_Controls();
+}
 
 
 ///////////////////////////////////////////////////////////
@@ -320,15 +409,15 @@ void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 	{
 		switch( event.GetKeyCode() )
 		{
-		case 'A': Play_Pos_Add();	return;
-		case 'D': Play_Pos_Del();	return;
-		case 'X': Play_Pos_Clr();	return;
+		case 'A': Play_Pos_Add    (); return;
+		case 'D': Play_Pos_Del    (); return;
+		case 'X': Play_Pos_Clr    (); return;
 
-		case 'P': Play_Once   ();	return;
-		case 'L': Play_Loop   ();	return;
-		case 'S': Play_Save   ();	return;
+		case 'P': Play_Once       (); return;
+		case 'L': Play_Loop       (); return;
+		case 'S': Play_Save       (); return;
 
-		case 'C': Save_toClipboard();	return;
+		case 'C': Save_toClipboard(); return;
 		}
 
 		event.Skip();
@@ -360,13 +449,11 @@ void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 			m_Projector.Inc_xRotation( 4. * M_DEG_TO_RAD);
 			break;
 
-		case WXK_F3:
-			m_Projector.Inc_yRotation(-4. * M_DEG_TO_RAD);
-			break;
+		case WXK_F1: m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() -  0.5); break;
+		case WXK_F2: m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() +  0.5); break;
 
-		case WXK_F4:
-			m_Projector.Inc_yRotation( 4. * M_DEG_TO_RAD);
-			break;
+		case WXK_F3: m_Projector.Inc_yRotation(-4. * M_DEG_TO_RAD); break;
+		case WXK_F4: m_Projector.Inc_yRotation( 4. * M_DEG_TO_RAD); break;
 
 		case WXK_RIGHT: case WXK_NUMPAD_RIGHT: case WXK_MULTIPLY: case WXK_NUMPAD_MULTIPLY:
 			m_Projector.Inc_zRotation(-4. * M_DEG_TO_RAD);
@@ -376,32 +463,26 @@ void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 			m_Projector.Inc_zRotation( 4. * M_DEG_TO_RAD);
 			break;
 
-		case WXK_INSERT  : m_Projector.Inc_xShift(-10.); break;
-		case WXK_DELETE  : m_Projector.Inc_xShift( 10.); break;
-		case WXK_HOME    : m_Projector.Inc_yShift(-10.); break;
-		case WXK_END     : m_Projector.Inc_yShift( 10.); break;
-		case WXK_PAGEUP  : m_Projector.Inc_zShift(-10.); break;
-		case WXK_PAGEDOWN: m_Projector.Inc_zShift( 10.); break;
+		case WXK_INSERT  : m_Projector.Inc_xShift(-0.1); break;
+		case WXK_DELETE  : m_Projector.Inc_xShift( 0.1); break;
+		case WXK_HOME    : m_Projector.Inc_yShift(-0.1); break;
+		case WXK_END     : m_Projector.Inc_yShift( 0.1); break;
+		case WXK_PAGEUP  : m_Projector.Inc_zShift(-0.1); break;
+		case WXK_PAGEDOWN: m_Projector.Inc_zShift( 0.1); break;
 
-		case 'B':
-			m_Parameters("BOX"   )->Set_Value(m_Parameters("BOX"   )->asBool() == false);
-			break;
+		case 'O': m_Projector.Inc_Central_Distance( 0.1); break;
+		case 'P': m_Projector.Inc_Central_Distance(-0.1); break;
 
-		case 'L':
-			m_Parameters("LABELS")->Set_Value(m_Parameters("LABELS")->asBool() == false);
-			break;
+		case 'B': Parameter_Value_Toggle("BOX"   ); return;
+		case 'L': Parameter_Value_Toggle("LABELS"); return;
+		case 'N': Parameter_Value_Toggle("NORTH" ); return;
+		case 'S': Parameter_Value_Toggle("STEREO"); return;
 
-		case 'N':
-			m_Parameters("NORTH" )->Set_Value(m_Parameters("NORTH" )->asBool() == false);
-			break;
-
-		case 'S':
-			m_Parameters("STEREO")->Set_Value(m_Parameters("STEREO")->asBool() == false);
-			break;
+		case 'A': Parameter_Value_Add("STEREO_DIST", -0.5); return;
+		case 'D': Parameter_Value_Add("STEREO_DIST",  0.5); return;
 		}
 
-		Update_Parent();
-		Update_View();
+		Update_Parent(); Update_View();
 	}
 }
 
@@ -419,9 +500,9 @@ void CSG_3DView_Panel::On_Mouse_LDown(wxMouseEvent &event)
 {
 	SetFocus();
 
-	m_Down_Screen	= event.GetPosition();
-	m_Down_Value.x	= m_Projector.Get_zRotation();
-	m_Down_Value.y	= m_Projector.Get_xRotation();
+	m_Down_Screen  = event.GetPosition();
+	m_Down_Value.x = m_Projector.Get_zRotation();
+	m_Down_Value.y = m_Projector.Get_xRotation();
 
 	CaptureMouse();
 }
@@ -438,8 +519,7 @@ void CSG_3DView_Panel::On_Mouse_LUp(wxMouseEvent &event)
 		m_Projector.Set_zRotation(m_Down_Value.x + GET_MOUSE_X_RELDIFF * M_PI_180);
 		m_Projector.Set_xRotation(m_Down_Value.y + GET_MOUSE_Y_RELDIFF * M_PI_180);
 
-		Update_View();
-		Update_Parent();
+		Update_View(); Update_Parent();
 	}
 }
 
@@ -448,9 +528,9 @@ void CSG_3DView_Panel::On_Mouse_RDown(wxMouseEvent &event)
 {
 	SetFocus();
 
-	m_Down_Screen	= event.GetPosition();
-	m_Down_Value.x	= m_Projector.Get_xShift();
-	m_Down_Value.y	= m_Projector.Get_yShift();
+	m_Down_Screen  = event.GetPosition();
+	m_Down_Value.x = m_Projector.Get_xShift();
+	m_Down_Value.y = m_Projector.Get_yShift();
 
 	CaptureMouse();
 }
@@ -464,11 +544,10 @@ void CSG_3DView_Panel::On_Mouse_RUp(wxMouseEvent &event)
 
 	if( m_Down_Screen.x != event.GetX() || m_Down_Screen.y != event.GetY() )
 	{
-		m_Projector.Set_xShift(m_Down_Value.x - (m_Down_Screen.x - event.GetX()));
-		m_Projector.Set_yShift(m_Down_Value.y - (m_Down_Screen.y - event.GetY()));
+		m_Projector.Set_xShift(m_Down_Value.x - GET_MOUSE_X_RELDIFF);
+		m_Projector.Set_yShift(m_Down_Value.y - GET_MOUSE_Y_RELDIFF);
 
-		Update_View();
-		Update_Parent();
+		Update_View(); Update_Parent();
 	}
 }
 
@@ -477,9 +556,10 @@ void CSG_3DView_Panel::On_Mouse_MDown(wxMouseEvent &event)
 {
 	SetFocus();
 
-	m_Down_Screen	= event.GetPosition();
-	m_Down_Value.x	= m_Projector.Get_yRotation();
-	m_Down_Value.y	= m_Projector.Get_zShift();
+	m_Down_Screen  = event.GetPosition();
+//	m_Down_Value.x = m_Projector.Get_yRotation();
+	m_Down_Value.x = m_Parameters("Z_SCALE")->asDouble();
+	m_Down_Value.y = m_Projector.Get_zShift();
 
 	CaptureMouse();
 }
@@ -493,11 +573,10 @@ void CSG_3DView_Panel::On_Mouse_MUp(wxMouseEvent &event)
 
 	if( m_Down_Screen.x != event.GetX() || m_Down_Screen.y != event.GetY() )
 	{
-		m_Projector.Set_yRotation(m_Down_Value.x + GET_MOUSE_X_RELDIFF * M_PI_180);
-		m_Projector.Set_zShift   (m_Down_Value.y + (m_Down_Screen.y - event.GetY()));
+	//	m_Projector.Set_yRotation(m_Down_Value.x + GET_MOUSE_X_RELDIFF * M_PI_180);
+		m_Projector.Set_zShift   (m_Down_Value.y + GET_MOUSE_Y_RELDIFF);
 
-		Update_View();
-		Update_Parent();
+		Update_View(); Update_Parent();
 	}
 }
 
@@ -513,21 +592,21 @@ void CSG_3DView_Panel::On_Mouse_Motion(wxMouseEvent &event)
 		}
 		else if( event.RightIsDown() )
 		{
-			m_Projector.Set_xShift   (m_Down_Value.x - (m_Down_Screen.x - event.GetX()));
-			m_Projector.Set_yShift   (m_Down_Value.y - (m_Down_Screen.y - event.GetY()));
+			m_Projector.Set_xShift(m_Down_Value.x - GET_MOUSE_X_RELDIFF);
+			m_Projector.Set_yShift(m_Down_Value.y - GET_MOUSE_Y_RELDIFF);
 		}
 		else if( event.MiddleIsDown() )
 		{
-			m_Projector.Set_yRotation(m_Down_Value.x + GET_MOUSE_X_RELDIFF * M_PI_180);
-			m_Projector.Set_zShift   (m_Down_Value.y + (m_Down_Screen.y - event.GetY()));
+		//	m_Projector.Set_yRotation         (m_Down_Value.x + GET_MOUSE_X_RELDIFF * M_PI_180);
+			m_Parameters("Z_SCALE")->Set_Value(m_Down_Value.x + GET_MOUSE_X_RELDIFF * 100.);
+			m_Projector.Set_zShift            (m_Down_Value.y + GET_MOUSE_Y_RELDIFF);
 		}
 		else
 		{
 			return;
 		}
 
-		Update_View();
-		Update_Parent();
+		Update_View(); Update_Parent();
 	}
 }
 
@@ -536,13 +615,29 @@ void CSG_3DView_Panel::On_Mouse_Wheel(wxMouseEvent &event)
 {
 	if( event.GetWheelRotation() )
 	{
-		m_Projector.Set_zShift(m_Projector.Get_zShift()	+ event.GetWheelRotation());
+		m_Projector.Set_zShift(m_Projector.Get_zShift()	+ event.GetWheelRotation() * 0.001);
 
 		Update_View();
 	}
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_3DView_Panel::On_Before_Draw(void)
+{
+	if( m_Play_State == SG_3DVIEW_PLAY_STOP )
+	{
+		m_Projector.Set_zScaling(m_Projector.Get_xScaling() * m_Parameters("Z_SCALE")->asDouble());
+	}
+
+	return( true );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -575,12 +670,14 @@ bool CSG_3DView_Panel::Update_View(bool bStatistics)
 	//-----------------------------------------------------
 	if( m_Play_State == SG_3DVIEW_PLAY_STOP )
 	{
-		m_bgColor = m_Parameters("BGCOLOR"    )->asColor ();
-		m_bBox    = m_Parameters("BOX"        )->asBool  ();
-		m_bLabels = m_Parameters("LABELS"     )->asBool  ();
-		m_bNorth  = m_Parameters("NORTH"      )->asBool  ();
-		m_bStereo = m_Parameters("STEREO"     )->asBool  ();
-		m_dStereo = m_Parameters("STEREO_DIST")->asDouble();
+		m_bgColor     = m_Parameters("BGCOLOR"    )->asColor ();
+		m_bBox        = m_Parameters("BOX"        )->asBool  ();
+		m_bStereo     = m_Parameters("STEREO"     )->asBool  ();
+		m_dStereo     = m_Parameters("STEREO_DIST")->asDouble();
+		m_bNorth      = m_Parameters("NORTH"      )->asBool  ();
+		m_Labels      = m_Parameters("LABELS"     )->asInt   ();
+		m_Label_Res   = m_Parameters("LABEL_RES"  )->asInt   ();
+		m_Label_Scale = m_Parameters("LABEL_SCALE")->asDouble();
 
 		switch( m_Parameters("DRAPE_MODE") ? m_Parameters("DRAPE_MODE")->asInt() : 0 )
 		{
