@@ -50,6 +50,7 @@
 //---------------------------------------------------------
 #include <wx/event.h>
 #include <wx/menu.h>
+#include <wx/toolbar.h>
 
 #include <saga_api/saga_api.h>
 
@@ -58,6 +59,8 @@
 
 #include "saga_frame.h"
 
+#include "wksp_tool_manager.h"
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -326,7 +329,7 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_LAYOUT_ZOOM_ORIGINAL:	return( _TL("Zoom to 100%") );
 	case ID_CMD_LAYOUT_ITEM_MAP:		return( _TL("Map") );
 	case ID_CMD_LAYOUT_ITEM_LEGEND:		return( _TL("Legend") );
-	case ID_CMD_LAYOUT_ITEM_SCALEBAR:	return( _TL("Scalebar") );
+	case ID_CMD_LAYOUT_ITEM_SCALEBAR:	return( _TL("Scale Bar") );
 	case ID_CMD_LAYOUT_ITEM_SCALE:		return( _TL("Scale") );
 	case ID_CMD_LAYOUT_ITEM_LABEL:		return( _TL("Label") );
 	case ID_CMD_LAYOUT_ITEM_TEXT:		return( _TL("Text") );
@@ -413,12 +416,6 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_DATA_PROJECT_NEW:		return( ID_IMG_TB_NEW_PROJECT );
 	case ID_CMD_TOOL_OPEN:				return( ID_IMG_TB_OPEN_TOOL );
 	case ID_CMD_TOOL_SEARCH:			return( ID_IMG_NB_WKSP_TOOLS );
-	case ID_CMD_TABLE_OPEN:				return( ID_IMG_TB_OPEN_TABLE );
-	case ID_CMD_SHAPES_OPEN:			return( ID_IMG_TB_OPEN_SHAPES );
-	case ID_CMD_GRID_OPEN:				return( ID_IMG_TB_OPEN_GRID );
-	case ID_CMD_GRIDS_OPEN:				return( ID_IMG_TB_OPEN_GRID );
-	case ID_CMD_TIN_OPEN:				return( ID_IMG_TB_OPEN_TIN );
-	case ID_CMD_POINTCLOUD_OPEN:		return( ID_IMG_TB_OPEN_POINTCLOUD );
 
 	case ID_CMD_MAP_MODE_DISTANCE:		return( ID_IMG_TB_MAP_MODE_DISTANCE );
 	case ID_CMD_MAP_MODE_SELECT:		return( ID_IMG_TB_MAP_MODE_SELECT );
@@ -469,7 +466,7 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_LAYOUT_PRINT_SETUP:		return( ID_IMG_TB_LAYOUT_PRINT_SETUP );
 	case ID_CMD_LAYOUT_PRINT_PREVIEW:	return( ID_IMG_TB_LAYOUT_PRINT_PREVIEW );
 	case ID_CMD_LAYOUT_PRINT:			return( ID_IMG_TB_LAYOUT_PRINT );
-	case ID_CMD_LAYOUT_EXPORT:			return( ID_IMG_TB_SAVE );
+	case ID_CMD_LAYOUT_EXPORT:			return( ID_IMG_TB_LAYOUT_EXPORT );
 	case ID_CMD_LAYOUT_TO_CLIPBOARD:	return( ID_IMG_TB_CLIPBOARD );
 	case ID_CMD_LAYOUT_ZOOM_IN:			return( ID_IMG_TB_ZOOM_IN );
 	case ID_CMD_LAYOUT_ZOOM_OUT:		return( ID_IMG_TB_ZOOM_OUT );
@@ -484,7 +481,7 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_TABLE_RECORD_DEL_ALL:	return( ID_IMG_TB_TABLE_ROW_DEL_ALL );
 	case ID_CMD_TABLE_SELECTION_ONLY:	return( ID_IMG_TB_TABLE_SELECTION_ONLY );
 
-	case ID_CMD_HISTOGRAM_PARAMETERS    :	return( ID_IMG_WND_HISTOGRAM );
+	case ID_CMD_HISTOGRAM_PARAMETERS    :	return( ID_IMG_TB_HISTOGRAM_PARAMETERS );
 	case ID_CMD_HISTOGRAM_CUMULATIVE    :	return( ID_IMG_TB_HISTOGRAM_CUMULATIVE );
 	case ID_CMD_HISTOGRAM_GAUSSIAN      :	return( ID_IMG_TB_HISTOGRAM_GAUSSIAN );
 	case ID_CMD_HISTOGRAM_AS_TABLE      :	return( ID_IMG_TB_HISTOGRAM_AS_TABLE );
@@ -496,9 +493,9 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_SCATTERPLOT_TO_CLIPBOARD:	return( ID_IMG_TB_CLIPBOARD );
 
 	case ID_CMD_DIAGRAM_PARAMETERS:		return( ID_IMG_TB_DIAGRAM_PARAMETERS );
-	case ID_CMD_DIAGRAM_SIZE_FIT:		break;
-	case ID_CMD_DIAGRAM_SIZE_INC:		return( ID_IMG_TB_MAP3D_CENTRAL_MORE );
-	case ID_CMD_DIAGRAM_SIZE_DEC:		return( ID_IMG_TB_MAP3D_CENTRAL_LESS );
+	case ID_CMD_DIAGRAM_SIZE_FIT:		return( ID_IMG_TB_ZOOM_FULL );
+	case ID_CMD_DIAGRAM_SIZE_INC:		return( ID_IMG_TB_ZOOM_IN );
+	case ID_CMD_DIAGRAM_SIZE_DEC:		return( ID_IMG_TB_ZOOM_OUT );
 	}
 
 	return( ID_IMG_DEFAULT );
@@ -547,7 +544,18 @@ void CMD_Menu_Ins_Item(wxMenu *pMenu, bool bCheck, int Cmd_ID, int Position)
 //---------------------------------------------------------
 wxToolBarBase * CMD_ToolBar_Create(int ID)
 {
-	return( g_pSAGA_Frame ? g_pSAGA_Frame->TB_Create(ID) : NULL );
+	if( g_pSAGA_Frame )
+	{
+		wxToolBar *pToolBar = new wxToolBar(g_pSAGA_Frame, ID, wxDefaultPosition, wxDefaultSize, wxTB_HORIZONTAL|wxTB_FLAT|wxTB_NODIVIDER);
+
+		int Size = g_pSAGA_Frame->FromDIP(g_pTools->Get_Parameter("LOOK_TB_SIZE")->asInt());
+
+		pToolBar->SetToolBitmapSize(wxSize(Size, Size));
+
+		return( pToolBar );
+	}
+
+	return( NULL );
 }
 
 //---------------------------------------------------------
@@ -555,26 +563,27 @@ void CMD_ToolBar_Add(wxToolBarBase *pToolBar, const wxString &Name)
 {
 	if( g_pSAGA_Frame )
 	{
-		g_pSAGA_Frame->TB_Add(pToolBar, Name);
+		g_pSAGA_Frame->Add_Toolbar(pToolBar, Name);
 	}
 }
 
 //---------------------------------------------------------
 void CMD_ToolBar_Add_Item(wxToolBarBase *pToolBar, bool bCheck, int Cmd_ID)
 {
-	if( g_pSAGA_Frame )
+	if( bCheck )
 	{
-		g_pSAGA_Frame->TB_Add_Item(pToolBar, bCheck, Cmd_ID);
+		pToolBar->AddTool(Cmd_ID, CMD_Get_Name(Cmd_ID), IMG_Get_Bitmaps(CMD_Get_ImageID(Cmd_ID), pToolBar->GetToolBitmapSize()), CMD_Get_Help(Cmd_ID), wxITEM_CHECK);
+	}
+	else
+	{
+		pToolBar->AddTool(Cmd_ID, CMD_Get_Name(Cmd_ID), IMG_Get_Bitmaps(CMD_Get_ImageID(Cmd_ID), pToolBar->GetToolBitmapSize()), CMD_Get_Help(Cmd_ID));
 	}
 }
 
 //---------------------------------------------------------
 void CMD_ToolBar_Add_Separator(wxToolBarBase *pToolBar)
 {
-	if( g_pSAGA_Frame )
-	{
-		g_pSAGA_Frame->TB_Add_Separator(pToolBar);
-	}
+	pToolBar->AddSeparator();
 }
 
 
