@@ -84,26 +84,18 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define DEF_LAYER_COLOUR_COUNT	15
+#define DEF_LAYER_COLOUR_COUNT	10
 
 //---------------------------------------------------------
 static int	s_Def_Layer_Colours[DEF_LAYER_COLOUR_COUNT]	=
 {
-	SG_COLOR_RED,
-	SG_COLOR_GREEN,
 	SG_COLOR_BLUE,
-	SG_COLOR_YELLOW,
-
-	SG_GET_RGB(255, 127,   0),
-	SG_COLOR_GREEN_LIGHT,
-	SG_COLOR_BLUE_LIGHT,
-	SG_GET_RGB(255, 255, 127),
-
-	SG_COLOR_RED_DARK,
-	SG_COLOR_GREEN_DARK,
-	SG_COLOR_BLUE_DARK,
+	SG_COLOR_GREEN,
+	SG_COLOR_RED,
 	SG_COLOR_YELLOW_DARK,
-
+	SG_COLOR_BLUE_DARK,
+	SG_COLOR_GREEN_DARK,
+	SG_COLOR_RED_DARK,
 	SG_COLOR_BLUE_GREEN,
 	SG_COLOR_PURPLE,
 	SG_COLOR_PINK
@@ -713,7 +705,11 @@ bool CWKSP_Layer::ColorsParms_Adjust(CSG_Parameters &Parameters, CSG_Data_Object
 //---------------------------------------------------------
 void CWKSP_Layer::On_DataObject_Changed(void)
 {
+    SG_UI_Process_Set_Busy(true);
+
 	ColorsParms_Adjust(m_Parameters);
+
+    SG_UI_Process_Set_Busy(false);
 }
 
 
@@ -764,9 +760,9 @@ int CWKSP_Layer::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 		{
 			int		Value	= pParameter->asInt();
 
-			pParameters->Set_Enabled("METRIC_COLORS" , Value == CLASSIFY_DISCRETE || Value == CLASSIFY_GRADUATED);
-			pParameters->Set_Enabled("NODE_SINGLE", Value == CLASSIFY_SINGLE);
-			pParameters->Set_Enabled("NODE_LUT"      , Value == CLASSIFY_LUT);
+			pParameters->Set_Enabled("METRIC_COLORS", Value == CLASSIFY_DISCRETE || Value == CLASSIFY_GRADUATED);
+			pParameters->Set_Enabled("NODE_SINGLE"  , Value == CLASSIFY_SINGLE);
+			pParameters->Set_Enabled("NODE_LUT"     , Value == CLASSIFY_LUT);
 		
 			if( m_pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_Grids )
 			{
@@ -1132,7 +1128,7 @@ bool CWKSP_Layer::View_Closes(MDI_ChildFrame *pView)
 {
 	if( pView == m_pHistogram )
 	{
-		m_pHistogram	= NULL;
+		m_pHistogram = NULL;
 	}
 
 	return( CWKSP_Data_Item::View_Closes(pView) );
@@ -1148,12 +1144,11 @@ void CWKSP_Layer::Histogram_Show(bool bShow)
 {
 	if( bShow && !m_pHistogram )
 	{
-		m_pHistogram	= new CVIEW_Histogram(this);
+		m_pHistogram = new CVIEW_Histogram(this);
 	}
 	else if( !bShow && m_pHistogram )
 	{
 		m_pHistogram->Destroy();
-		delete(m_pHistogram);
 	}
 }
 
@@ -1182,7 +1177,7 @@ bool CWKSP_Layer::Edit_On_Key_Down(int KeyCode)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Layer::Edit_On_Mouse_Down(CSG_Point Point, double ClientToWorld, int Key)
+bool CWKSP_Layer::Edit_On_Mouse_Down(const CSG_Point &Point, double ClientToWorld, int Key)
 {
 	m_Edit_Mouse_Down	= Point;
 
@@ -1190,13 +1185,25 @@ bool CWKSP_Layer::Edit_On_Mouse_Down(CSG_Point Point, double ClientToWorld, int
 }
 
 //---------------------------------------------------------
-bool CWKSP_Layer::Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, int Key)
+bool CWKSP_Layer::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld, int Key)
 {
 	return( false );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Layer::Edit_On_Mouse_Move(wxWindow *pMap, CSG_Rect rWorld, wxPoint pt, wxPoint ptLast, int Key)
+bool CWKSP_Layer::Edit_On_Mouse_Move(wxWindow *pMap, const CSG_Rect &rWorld, const wxPoint &Point, const wxPoint &Last, int Key)
+{
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Layer::Edit_On_Mouse_Move_Draw(wxDC &dc, const CSG_Rect &rWorld, const wxPoint &Point)
+{
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Layer::Edit_Do_Mouse_Move_Draw(bool bMouseDown)
 {
 	return( false );
 }
