@@ -696,6 +696,8 @@ bool CWKSP_Map::Serialize(CSG_MetaData &Root, const wxString &ProjectDir, bool b
 		}
 
 		//-------------------------------------------------
+        SG_UI_Process_Set_Busy(true);
+
 		CSG_MetaData	&Layers	= *Root.Get_Child("LAYERS");	int	nLayers	= 0;
 
 		m_Parameters["CRS_CHECK"].Set_Value(false);
@@ -748,6 +750,8 @@ bool CWKSP_Map::Serialize(CSG_MetaData &Root, const wxString &ProjectDir, bool b
 
 		m_Parameters["CRS_CHECK"].Set_Value(true);
 
+        SG_UI_Process_Set_Busy(false);
+
 		if( nLayers < 1 )
 		{
 			return( false );
@@ -1439,9 +1443,9 @@ void CWKSP_Map::View_Show(bool bShow)
 		}
 		else
 		{
-			View_Refresh(false);
-
 			m_pView->Activate();
+
+			View_Refresh(false);
 		}
 	}
 	else if( m_pView )
