@@ -168,7 +168,7 @@ wxMenu * CWKSP_PointCloud::Get_Menu(void)
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVEAS);
 
-	if( m_pObject->is_File_Native() && m_pObject->is_Modified() )
+	if( m_pObject->is_Modified() && SG_File_Exists(m_pObject->Get_File_Name(false)) )
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_RELOAD);
 
 	if( m_pObject->is_File_Native() )
@@ -339,6 +339,10 @@ bool CWKSP_PointCloud::On_Command_UI(wxUpdateUIEvent &event)
 	case ID_CMD_TABLE_DIAGRAM:
 		event.Check(m_pTable->Get_Diagram() != NULL);
 		break;
+
+	case ID_CMD_SHAPES_HISTOGRAM:
+		event.Check(m_pHistogram != NULL);
+		break;
 	}
 
 	return( true );
@@ -845,7 +849,7 @@ TSG_Rect CWKSP_PointCloud::Edit_Get_Extent(void)
 }
 
 //---------------------------------------------------------
-bool CWKSP_PointCloud::Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, int Key)
+bool CWKSP_PointCloud::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld, int Key)
 {
 	if( Key & TOOL_INTERACTIVE_KEY_RIGHT )
 	{
