@@ -298,14 +298,14 @@ CTree_Growth::CTree_Growth(void)
 
 	Add_Reference("Karger, D.N., Kessler, M., Conrad, O., Weigelt, P., Kreft, H., Knig, C., Zimmermann, N.E.", "2019",
 		"Why tree lines are lower on islands - Climatic and biogeographic effects hold the answer",
-		"Global Ecol. Biogeogr., 00:112, doi:10.1111/geb.12897.",
-		SG_T("https://onlinelibrary.wiley.com/doi/full/10.1111/geb.12897"), _TL("online")
+		"Global Ecol. Biogeogr., 00:112.",
+		SG_T("https://doi.org/10.1111/geb.12897"), _TL("doi:10.1111/geb.12897")
 	);
 
 	Add_Reference("Paulsen, J. / Krner, C.", "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112. doi:10.1007/s00035-014-0124-0.",
-		SG_T("http://link.springer.com/article/10.1007%2Fs00035-014-0124-0"), _TL("online")
+		"Alpine Botany, 124:1, 112.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
@@ -416,6 +416,11 @@ CTree_Growth::CTree_Growth(void)
 //---------------------------------------------------------
 int CTree_Growth::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
+	if( pParameter->Cmp_Identifier("TLH") )
+	{
+		pParameters->Set_Enabled("TLH_MAX_DIFF", pParameter->asPointer() != NULL);
+	}
+
 	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
 }
 
@@ -571,8 +576,8 @@ CWater_Balance::CWater_Balance(void)
 
 	Add_Reference("Paulsen, J. / Krner, C.", "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112. doi:10.1007/s00035-014-0124-0.",
-		SG_T("http://link.springer.com/article/10.1007%2Fs00035-014-0124-0"), _TL("online")
+		"Alpine Botany, 124:1, 112.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
@@ -750,8 +755,8 @@ CWater_Balance_Interactive::CWater_Balance_Interactive(void)
 
 	Add_Reference("Paulsen, J. / Krner, C.", "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112. doi:10.1007/s00035-014-0124-0.",
-		SG_T("http://link.springer.com/article/10.1007%2Fs00035-014-0124-0"), _TL("online")
+		"Alpine Botany, 124:1, 112.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
