@@ -102,31 +102,38 @@ CGDAL_Import_WMS::CGDAL_Import_WMS(void)
 	Parameters.Add_Choice("",
 		"SERVER"	, _TL("Server"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s",
-			_TL("Open Street Map"),
-			_TL("Google Map"),
-			_TL("Google Satellite"),
-			_TL("Google Hybrid"),
-			_TL("Google Terrain"),
-			_TL("Google Terrain, Streets and Water"),
-			_TL("ArcGIS MapServer Tiles"),
-			_TL("TopPlusOpen"),
-			_TL("user defined")
+		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s",
+			SG_T("Open Street Map"),
+			SG_T("Google Map"),
+			SG_T("Google Satellite"),
+			SG_T("Google Hybrid"),
+			SG_T("Google Terrain"),
+			SG_T("Google Terrain, Streets and Water"),
+			SG_T("ArcGIS MapServer Tiles"),
+			SG_T("TopPlusOpen"),
+			SG_T("EMODnet Bathymetry WMTS service"),
+			SG_T("user defined")
 		), 0
 	);
 
-	Parameters.Add_Int("SERVER",
-		"BLOCKSIZE"	, _TL("Block Size"),
-		_TL(""),
-		256, 32, true
-	);
-
 	Parameters.Add_String("SERVER",
 		"SERVER_USER", _TL("Server"),
 		_TL(""),
 		"tile.openstreetmap.org/${z}/${x}/${y}.png"
 	);
 
+	Parameters.Add_Int("SERVER",
+		"SERVER_EPSG", _TL("EPSG"),
+		_TL(""),
+		3857
+	);
+
+	Parameters.Add_Int("SERVER",
+		"BLOCKSIZE"	, _TL("Block Size"),
+		_TL(""),
+		256, 32, true
+	);
+
 	Parameters.Add_Bool("",
 		"CACHE"		, _TL("Cache"),
 		_TL("Enable local disk cache. Allows for offline operation."),
@@ -164,53 +171,53 @@ CGDAL_Import_WMS::CGDAL_Import_WMS(void)
 //---------------------------------------------------------
 int CGDAL_Import_WMS::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	CSG_Parameter	*pXMin	= pParameters->Get_Parameter("XMIN");
-	CSG_Parameter	*pYMin	= pParameters->Get_Parameter("YMIN");
-	CSG_Parameter	*pXMax	= pParameters->Get_Parameter("XMAX");
-	CSG_Parameter	*pYMax	= pParameters->Get_Parameter("YMAX");
-	CSG_Parameter	*pNX	= pParameters->Get_Parameter("NX"  );
-	CSG_Parameter	*pNY	= pParameters->Get_Parameter("NY"  );
+	CSG_Parameter *pXMin = pParameters->Get_Parameter("XMIN");
+	CSG_Parameter *pYMin = pParameters->Get_Parameter("YMIN");
+	CSG_Parameter *pXMax = pParameters->Get_Parameter("XMAX");
+	CSG_Parameter *pYMax = pParameters->Get_Parameter("YMAX");
+	CSG_Parameter *pNX   = pParameters->Get_Parameter("NX"  );
+	CSG_Parameter *pNY   = pParameters->Get_Parameter("NY"  );
 
 	if( pParameter->Cmp_Identifier("NX") )
 	{
-		double	d	= fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
+		double d = fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
 		pNY  ->Set_Value(fabs(pYMax->asDouble() - pYMin->asDouble()) / d);
 		pYMax->Set_Value(pYMin->asDouble() + d * pNY->asDouble());
 	}
 
 	if( pParameter->Cmp_Identifier("NY") )
 	{
-		double	d	= fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
+		double d = fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
 		pNX  ->Set_Value(fabs(pXMax->asDouble() - pXMin->asDouble()) / d);
 		pXMax->Set_Value(pXMin->asDouble() + d * pNX->asDouble());
 	}
 
 	if( pParameter->Cmp_Identifier("XMIN") )
 	{
-		double	d	= fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
+		double d = fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
 		pNX  ->Set_Value(fabs(pXMax->asDouble() - pXMin->asDouble()) / d);
 		pXMax->Set_Value(pXMin->asDouble() + d * pNX->asDouble());
 	}
 
 	if( pParameter->Cmp_Identifier("YMIN") )
 	{
-		double	d	= fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
+		double d = fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
 		pNY  ->Set_Value(fabs(pYMax->asDouble() - pYMin->asDouble()) / d);
 		pYMax->Set_Value(pYMin->asDouble() + d * pNY->asDouble());
 	}
 
 	if( pParameter->Cmp_Identifier("XMAX") )
 	{
-		double	d	= fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
+		double d = fabs(pYMax->asDouble() - pYMin->asDouble()) / pNY->asDouble();
 		pNX  ->Set_Value(fabs(pXMax->asDouble() - pXMin->asDouble()) / d);
-		pYMax->Set_Value(pYMax->asDouble() - d * pNY->asDouble());
+		pYMax->Set_Value(pYMin->asDouble() + d * pNY->asDouble());
 	}
 
 	if( pParameter->Cmp_Identifier("YMAX") )
 	{
-		double	d	= fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
+		double d = fabs(pXMax->asDouble() - pXMin->asDouble()) / pNX->asDouble();
 		pNY  ->Set_Value(fabs(pYMax->asDouble() - pYMin->asDouble()) / d);
-		pXMax->Set_Value(pXMax->asDouble() - d * pNX->asDouble());
+		pXMax->Set_Value(pXMin->asDouble() + d * pNX->asDouble());
 	}
 
 	return( CSG_Tool::On_Parameter_Changed(pParameters, pParameter) );
@@ -227,7 +234,10 @@ int CGDAL_Import_WMS::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 
 	if( pParameter->Cmp_Identifier("SERVER") )
 	{
-		pParameters->Set_Enabled("SERVER_USER", pParameter->asInt() >= pParameter->asChoice()->Get_Count() - 1);
+		bool bUser = pParameter->asInt() >= pParameter->asChoice()->Get_Count() - 1;
+
+		pParameters->Set_Enabled("SERVER_USER", bUser);
+		pParameters->Set_Enabled("SERVER_EPSG", bUser);
 	}
 
 	if( pParameter->Cmp_Identifier("CACHE") )
@@ -249,13 +259,13 @@ bool CGDAL_Import_WMS::On_Execute(void)
 	//-----------------------------------------------------
 	CSG_Grid_System	System;
 
-	if( !Get_System(System, Parameters("TARGET")->asGrid()) )
+	if( !Get_WMS_System(System, Parameters("TARGET")->asGrid()) )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	CSG_Grid	*pBands[3];
+	CSG_Grid *pBands[3];
 
 	if( !Get_Bands(pBands, System) )
 	{
@@ -280,17 +290,31 @@ bool CGDAL_Import_WMS::On_Execute(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CGDAL_Import_WMS::Get_System(CSG_Grid_System &System, CSG_Grid *pTarget)
+CSG_Projection CGDAL_Import_WMS::Get_WMS_Projection(void)
+{
+	CSG_Projection Projection(Parameters("SERVER")->asInt() >= Parameters("SERVER")->asChoice()->Get_Count()
+		? Parameters("SERVER_EPSG")->asInt() : 3857
+	); // predefines default to EPSG:3857 => Web Mercator
+
+	if( Projection.is_Okay() == false )
+	{
+		Projection.Set_GCS_WGS84();
+	}
+
+	return( Projection );
+}
+
+//---------------------------------------------------------
+bool CGDAL_Import_WMS::Get_WMS_System(CSG_Grid_System &System, CSG_Grid *pTarget)
 {
-	//-----------------------------------------------------
 	if( !pTarget )
 	{
-		CSG_Rect	Extent(
+		CSG_Rect Extent(
 			Parameters("XMIN")->asDouble(), Parameters("YMIN")->asDouble(),
 			Parameters("XMAX")->asDouble(), Parameters("YMAX")->asDouble()
 		);
 
-		double	Cellsize	= Extent.Get_XRange() / Parameters("NX")->asDouble();
+		double Cellsize = Extent.Get_XRange() / Parameters("NX")->asDouble();
 
 		return( System.Assign(Cellsize, Extent) );
 	}
@@ -301,11 +325,11 @@ bool CGDAL_Import_WMS::Get_System(CSG_Grid_System &System, CSG_Grid *pTarget)
 		return( false );
 	}
 
-	CSG_Shapes	rTarget(SHAPE_TYPE_Point), rSource;
+	CSG_Shapes rTarget(SHAPE_TYPE_Point), rSource;
 
-	rTarget.Get_Projection()	= pTarget->Get_Projection();
+	rTarget.Get_Projection() = pTarget->Get_Projection();
 
-	CSG_Rect	Extent	= pTarget->Get_Extent(true);
+	CSG_Rect Extent = pTarget->Get_Extent(true);
 
 	rTarget.Add_Shape()->Add_Point(Extent.Get_XMin   (), Extent.Get_YMin   ());
 	rTarget.Add_Shape()->Add_Point(Extent.Get_XMin   (), Extent.Get_YCenter());
@@ -317,35 +341,19 @@ bool CGDAL_Import_WMS::Get_System(CSG_Grid_System &System, CSG_Grid *pTarget)
 	rTarget.Add_Shape()->Add_Point(Extent.Get_XCenter(), Extent.Get_YMin   ());
 
 	//-----------------------------------------------------
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 2);	// Coordinate Transformation (Shapes);
-
-	if(	!pTool )
+	if( !SG_Get_Projected(&rTarget, &rSource, Get_WMS_Projection()) )
 	{
 		return( false );
 	}
 
-	pTool->Set_Manager(NULL);
+	Extent = rSource.Get_Extent();
 
-	if( SG_TOOL_PARAMETER_SET("CRS_PROJ4", SG_T("+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +k=1.0"))
-	&&  SG_TOOL_PARAMETER_SET("SOURCE"   , &rTarget)
-	&&  SG_TOOL_PARAMETER_SET("TARGET"   , &rSource)
-	&&  pTool->Execute() )
-	{
-		Extent	= rSource.Get_Extent();
+	double Cellsize = Extent.Get_XRange() / pTarget->Get_NX() < Extent.Get_YRange() / pTarget->Get_NY()
+		            ? Extent.Get_XRange() / pTarget->Get_NX() : Extent.Get_YRange() / pTarget->Get_NY();
 
-		double	Cellsize	= Extent.Get_XRange() / pTarget->Get_NX() < Extent.Get_YRange() / pTarget->Get_NY()
-							? Extent.Get_XRange() / pTarget->Get_NX() : Extent.Get_YRange() / pTarget->Get_NY();
+	System.Assign(Cellsize, Extent);
 
-		System.Assign(Cellsize, Extent);
-
-		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
-
-		return( true );
-	}
-
-	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
-
-	return( false );
+	return( true );
 }
 
 
@@ -356,7 +364,7 @@ bool CGDAL_Import_WMS::Get_System(CSG_Grid_System &System, CSG_Grid *pTarget)
 //---------------------------------------------------------
 bool CGDAL_Import_WMS::Get_Projected(CSG_Grid *pBands[3], CSG_Grid *pTarget)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 3);	// Coordinate Transformation (Grid List);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 3);	// Coordinate Transformation (Grid List);
 
 	if(	!pTool )
 	{
@@ -378,9 +386,9 @@ bool CGDAL_Import_WMS::Get_Projected(CSG_Grid *pBands[3], CSG_Grid *pTarget)
 	{
 		CSG_Parameter_Grid_List	*pGrids	= pTool->Get_Parameters()->Get_Parameter("GRIDS")->asGridList();
 
-		delete(pBands[0]);	pBands[0]	= pGrids->Get_Grid(0);
-		delete(pBands[1]);	pBands[1]	= pGrids->Get_Grid(1);
-		delete(pBands[2]);	pBands[2]	= pGrids->Get_Grid(2);
+		delete(pBands[0]); pBands[0] = pGrids->Get_Grid(0);
+		delete(pBands[1]); pBands[1] = pGrids->Get_Grid(1);
+		delete(pBands[2]); pBands[2] = pGrids->Get_Grid(2);
 
 		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
@@ -400,12 +408,11 @@ bool CGDAL_Import_WMS::Get_Projected(CSG_Grid *pBands[3], CSG_Grid *pTarget)
 //---------------------------------------------------------
 bool CGDAL_Import_WMS::Set_Image(CSG_Grid *pBands[3])
 {
-	//-----------------------------------------------------
-	CSG_Grid	*pMap	= Parameters("TARGET_MAP")->asGrid();
+	CSG_Grid *pMap = Parameters("TARGET_MAP")->asGrid();
 
 	if( !pMap )
 	{
-		pMap	= SG_Create_Grid();
+		pMap = SG_Create_Grid();
 	}
 
 	if( !pMap->Get_System().is_Equal(pBands[0]->Get_System()) )
@@ -415,17 +422,17 @@ bool CGDAL_Import_WMS::Set_Image(CSG_Grid *pBands[3])
 
 	pMap->Set_Name(_TL("Open Street Map"));
 
-	pMap->Get_Projection()	= pBands[0]->Get_Projection();
+	pMap->Get_Projection() = pBands[0]->Get_Projection();
 
 	//-----------------------------------------------------
-	bool	bGrayscale	= Parameters("GRAYSCALE")->asBool();
+	bool bGrayscale = Parameters("GRAYSCALE")->asBool();
 
 	#pragma omp parallel for
 	for(int y=0; y<pMap->Get_NY(); y++)	for(int x=0; x<pMap->Get_NX(); x++)
 	{
 		if( bGrayscale )
 		{
-			double	z	= (pBands[0]->asInt(x, y) + pBands[1]->asInt(x, y) + pBands[2]->asInt(x, y)) / 3.0;
+			double z = (pBands[0]->asInt(x, y) + pBands[1]->asInt(x, y) + pBands[2]->asInt(x, y)) / 3.;
 
 			pMap->Set_Value(x, y, SG_GET_RGB(z, z, z));
 		}
@@ -455,8 +462,7 @@ bool CGDAL_Import_WMS::Set_Image(CSG_Grid *pBands[3])
 //---------------------------------------------------------
 bool CGDAL_Import_WMS::Get_Bands(CSG_Grid *pBands[3], const CSG_Grid_System &System)
 {
-	//-----------------------------------------------------
-	CSG_GDAL_DataSet	DataSet;
+	CSG_GDAL_DataSet DataSet;
 
 	if( DataSet.Open_Read(Get_Request(), System) == false || DataSet.Get_Count() != 3 )
 	{
@@ -473,18 +479,18 @@ bool CGDAL_Import_WMS::Get_Bands(CSG_Grid *pBands[3], const CSG_Grid_System &Sys
 	//-----------------------------------------------------
 	SG_UI_Progress_Lock(true);
 
-	pBands[0]	= DataSet.Read(0);
-	pBands[1]	= DataSet.Read(1);
-	pBands[2]	= DataSet.Read(2);
+	pBands[0] = DataSet.Read(0);
+	pBands[1] = DataSet.Read(1);
+	pBands[2] = DataSet.Read(2);
 
 	SG_UI_Progress_Lock(false);
 
 	//-----------------------------------------------------
 	if( !pBands[0] || !pBands[1] || !pBands[2] )
 	{
-		if( pBands[0] )	delete(pBands[0]);
-		if( pBands[1] )	delete(pBands[1]);
-		if( pBands[2] )	delete(pBands[2]);
+		if( pBands[0] ) delete(pBands[0]);
+		if( pBands[1] ) delete(pBands[1]);
+		if( pBands[2] ) delete(pBands[2]);
 
 		return( false );
 	}
@@ -500,53 +506,75 @@ bool CGDAL_Import_WMS::Get_Bands(CSG_Grid *pBands[3], const CSG_Grid_System &Sys
 //---------------------------------------------------------
 CSG_String CGDAL_Import_WMS::Get_Request(void)
 {
-	CSG_String	Server, Projection	= "EPSG:3857";
+	CSG_String Server;
 
 	switch( Parameters("SERVER")->asInt() )
 	{
-	default:	Server	= "tile.openstreetmap.org/${z}/${x}/${y}.png"                                                     ;	break;	// Open Street Map
-	case  1:	Server	= "mt.google.com/vt/lyrs=m&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Map
-	case  2:	Server	= "mt.google.com/vt/lyrs=s&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Satellite
-	case  3:	Server	= "mt.google.com/vt/lyrs=y&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Hybrid
-	case  4:	Server	= "mt.google.com/vt/lyrs=t&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Terrain
-	case  5:	Server	= "mt.google.com/vt/lyrs=p&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Terrain, Streets and Water
-	case  6:	Server	= "services.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/${z}/${y}/${x}" ;	break;	// ArcGIS MapServer Tiles
-	case  7:	Server	= "sgx.geodatenzentrum.de/wmts_topplus_open/tile/1.0.0/web/default/WEBMERCATOR/${z}/${y}/${x}.png";	break;	// TopPlusOpen
-	case  8:	Server	= Parameters("SERVER_USER")->asString()                                                           ;	break;	// user defined
-//	case  x:	Server	= "s3.amazonaws.com/com.modestmaps.bluemarble/${z}-r${y}-c${x}.jpg"                               ;	break;	// Blue Marble
+	case  0: Server = "tile.openstreetmap.org/${z}/${x}/${y}.png"                                                     ;	break;	// Open Street Map
+	case  1: Server = "mt.google.com/vt/lyrs=m&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Map
+	case  2: Server = "mt.google.com/vt/lyrs=s&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Satellite
+	case  3: Server = "mt.google.com/vt/lyrs=y&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Hybrid
+	case  4: Server = "mt.google.com/vt/lyrs=t&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Terrain
+	case  5: Server = "mt.google.com/vt/lyrs=p&x=${x}&y=${y}&z=${z}"                                                  ;	break;	// Google Terrain, Streets and Water
+	case  6: Server = "services.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/${z}/${y}/${x}" ;	break;	// ArcGIS MapServer Tiles
+	case  7: Server = "sgx.geodatenzentrum.de/wmts_topplus_open/tile/1.0.0/web/default/WEBMERCATOR/${z}/${y}/${x}.png";	break;	// TopPlusOpen
+	case  8: Server = "tiles.emodnet-bathymetry.eu/2020/baselayer/web_mercator/${z}/${x}/${y}.png"                    ; break;	// EMODnet
+	default: Server = Parameters("SERVER_USER")->asString();                                                          ;	break;	// user defined
+//	case  x: Server = "s3.amazonaws.com/com.modestmaps.bluemarble/${z}-r${y}-c${x}.jpg"                               ;	break;	// Blue Marble
 	}
 
 	//-----------------------------------------------------
-	CSG_MetaData	XML, *pEntry;
+	CSG_Projection Projection(Get_WMS_Projection());
+
+	TSG_Rect r;
+
+	if( Projection.is_Geographic() )
+	{
+		r.xMin = -180.; r.xMax = 180.;
+		r.yMin =  -90.; r.yMax =  90.;
+	}
+	else if( Projection.Get_Authority_ID() == 3857 ) // Web Mercator ?
+	{
+		r.xMin = -20037508.34; r.xMax = 20037508.34;
+		r.yMin = -20037508.34; r.yMax = 20037508.34;
+	}
+	else
+	{
+		SG_Get_Projected(CSG_Projections::Get_GCS_WGS84(), Projection, r);
+	}
+
+	//-----------------------------------------------------
+	CSG_MetaData XML, *pEntry;
 
 	XML.Set_Name("GDAL_WMS");
 
 	//-----------------------------------------------------
 	pEntry	= XML.Add_Child("Service");	pEntry->Add_Property("name", "TMS");
 
-	pEntry->Add_Child("ServerUrl"  , "http://" + Server);
+	pEntry->Add_Child("ServerUrl"  , "https://" + Server);
 
 	//-----------------------------------------------------
 	pEntry	= XML.Add_Child("DataWindow");		// Define size and extents of the data. (required, except for TiledWMS and VirtualEarth)
 
-	pEntry->Add_Child("UpperLeftX" , -20037508.34);		// X (longitude) coordinate of upper-left corner. (optional, defaults to -180.0, except for VirtualEarth)
-	pEntry->Add_Child("UpperLeftY" ,  20037508.34);		// Y (latitude) coordinate of upper-left corner. (optional, defaults to 90.0, except for VirtualEarth)
-	pEntry->Add_Child("LowerRightX",  20037508.34);		// X (longitude) coordinate of lower-right corner. (optional, defaults to 180.0, except for VirtualEarth)
-	pEntry->Add_Child("LowerRightY", -20037508.34);		// Y (latitude) coordinate of lower-right corner. (optional, defaults to -90.0, except for VirtualEarth)
-	pEntry->Add_Child("TileLevel"  ,           18);		// Tile level at highest resolution. (tiled image sources only, optional, defaults to 0)
-	pEntry->Add_Child("TileCountX" ,            1);		// Can be used to define image size, SizeX = TileCountX * BlockSizeX * 2TileLevel. (tiled image sources only, optional, defaults to 0)
-	pEntry->Add_Child("TileCountY" ,            1);		// Can be used to define image size, SizeY = TileCountY * BlockSizeY * 2TileLevel. (tiled image sources only, optional, defaults to 0)
-	pEntry->Add_Child("YOrigin"    ,        "top");		// Can be used to define the position of the Y origin with respect to the tile grid. Possible values are 'top', 'bottom', and 'default', where the default behavior is mini-driver-specific. (TMS mini-driver only, optional, defaults to 'bottom' for TMS)
+	pEntry->Add_Child("UpperLeftX" ,         r.xMin);	// X (longitude) coordinate of upper-left corner. (optional, defaults to -180.0, except for VirtualEarth)
+	pEntry->Add_Child("UpperLeftY" ,         r.yMax);	// Y (latitude) coordinate of upper-left corner. (optional, defaults to 90.0, except for VirtualEarth)
+	pEntry->Add_Child("LowerRightX",         r.xMax);	// X (longitude) coordinate of lower-right corner. (optional, defaults to 180.0, except for VirtualEarth)
+	pEntry->Add_Child("LowerRightY",         r.yMin);	// Y (latitude) coordinate of lower-right corner. (optional, defaults to -90.0, except for VirtualEarth)
+
+	pEntry->Add_Child("TileLevel"  ,             18);	// Tile level at highest resolution. (tiled image sources only, optional, defaults to 0)
+	pEntry->Add_Child("TileCountX" ,              1);	// Can be used to define image size, SizeX = TileCountX * BlockSizeX * 2TileLevel. (tiled image sources only, optional, defaults to 0)
+	pEntry->Add_Child("TileCountY" ,              1);	// Can be used to define image size, SizeY = TileCountY * BlockSizeY * 2TileLevel. (tiled image sources only, optional, defaults to 0)
+	pEntry->Add_Child("YOrigin"    ,          "top");	// Can be used to define the position of the Y origin with respect to the tile grid. Possible values are 'top', 'bottom', and 'default', where the default behavior is mini-driver-specific. (TMS mini-driver only, optional, defaults to 'bottom' for TMS)
 
 	//-----------------------------------------------------
-	if( !Projection.is_Empty() )
-	{
-		pEntry	= XML.Add_Child("Projection", Projection);	// Image projection (optional, defaults to value reported by mini-driver or EPSG:4326)
-	}
+	CSG_String CRS(CSG_String::Format("EPSG:%d", Projection.Get_Authority_ID()));
 
+	pEntry	= XML.Add_Child("Projection",       CRS);	// Image projection (optional, defaults to value reported by mini-driver or EPSG:4326)
+
+	//-----------------------------------------------------
 	pEntry	= XML.Add_Child("BandsCount",         3);	// Number of bands/channels, 1 for grayscale data, 3 for RGB, 4 for RGBA. (optional, defaults to 3)
 
-	int	Blocksize	= Parameters("BLOCKSIZE")->asInt();
+	int Blocksize = Parameters("BLOCKSIZE")->asInt();
 	pEntry	= XML.Add_Child("BlockSizeX", Blocksize);	// Block size in pixels. (optional, defaults to 1024, except for VirtualEarth)
 	pEntry	= XML.Add_Child("BlockSizeY", Blocksize);
 
@@ -562,7 +590,7 @@ CSG_String CGDAL_Import_WMS::Get_Request(void)
 			Path	= SG_Dir_Get_Temp();
 		}
 
-		pEntry->Add_Child("Path", SG_File_Make_Path(Path, SG_T("gdalwmscache")));
+		pEntry->Add_Child("Path", SG_File_Make_Path(Path, "gdalwmscache"));
 	}
 
 	//-----------------------------------------------------
